import { createElement } from 'react';
import { B as FrameState } from '../types-bdYZNS1C.js';
import { FrameUIComponents, FrameUIComponentStylingProps } from './types.js';
import 'frames.js';
import 'frames.js/frame-parsers';
import '@farcaster/core';

type BaseFrameUIProps<TStylingProps extends Record<string, unknown>> = {
    frameState: FrameState;
    /**
     * Renders also frames that contain only image and at least one button
     *
     * @defaultValue false
     */
    allowPartialFrame?: boolean;
    /**
     * Renders debug image if available
     */
    enableImageDebugging?: boolean;
    components: FrameUIComponents<TStylingProps>;
    theme?: Partial<FrameUIComponentStylingProps<TStylingProps>> | undefined;
    /**
     * Called when an error occurs in response to frame button press
     *
     * @defaultValue console.error()
     */
    onError?: (error: Error) => void;
    /**
     * Custom createElement function to use when rendering components.
     *
     * This is useful for libraries like Nativewind that require a custom createElement function.
     *
     * @defaultValue React.createElement
     */
    createElement?: typeof createElement;
};
declare function BaseFrameUI<TStylingProps extends Record<string, unknown>>({ frameState, components, theme, allowPartialFrame, enableImageDebugging, onError, createElement, }: BaseFrameUIProps<TStylingProps>): JSX.Element | null;

export { BaseFrameUI, type BaseFrameUIProps };
